FlutterJs class

Constructors

FlutterJs()

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addChannel(String name, FlutterJsChannelCallbak fn, {String? dartChannelAddress}) → dynamic
dispose() → dynamic
eval(String code) → Future<String>
isReady() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMessageReceived(String? channel, String? message) → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

DEBUG ↔ bool
getter/setter pair
httpPassword → String?
no setter
httpPort → int?
no setter
platformVersion → Future<String?>
no setter

Static Methods

close(int? engineId) → Future<int?>
evaluate(String command, int? id, {String convertTo = ""}) → Future<String>
initEngine(int? engineId) → Future<int?>