JSStaticFunction class

struct JSStaticFunction This structure describes a statically declared function property.

Constructors

JSStaticFunction({required String name, Pointer<NativeFunction<JSObjectCallAsFunctionCallback>>? callAsFunction, JSPropertyAttributes attributes = JSPropertyAttributes.kJSPropertyAttributeNone})

Properties

attributes ↔ JSPropertyAttributes
A logically ORed set of JSPropertyAttributes to give to the property.
getter/setter pair
callAsFunction ↔ Pointer<NativeFunction<JSObjectCallAsFunctionCallback>>?
A JSObjectCallAsFunctionCallback to invoke when the property is called as a function.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
Property's name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() → Pointer<JSStaticFunction>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStruct() → JSStaticFunctionStruct

Operators

operator ==(Object other) → bool
The equality operator.
inherited