JSStaticValue class

struct JSStaticValue This structure describes a statically declared value property.

Constructors

JSStaticValue({required String name, Pointer<NativeFunction<JSObjectGetPropertyCallback>>? getProperty, Pointer<NativeFunction<JSObjectSetPropertyCallback>>? setProperty, JSPropertyAttributes attributes = JSPropertyAttributes.kJSPropertyAttributeNone})

Properties

attributes ↔ JSPropertyAttributes
(unsigned) A logically ORed set of JSPropertyAttributes to give to the property.
getter/setter pair
getProperty ↔ Pointer<NativeFunction<JSObjectGetPropertyCallback>>?
A JSObjectGetPropertyCallback to invoke when getting the property's value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
Property's name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setProperty ↔ Pointer<NativeFunction<JSObjectSetPropertyCallback>>?
A JSObjectSetPropertyCallback to invoke when setting the property's value. May be NULL if the ReadOnly attribute is set.
getter/setter pair

Methods

create() → Pointer<JSStaticValue>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStruct() → JSStaticValueStruct

Operators

operator ==(Object other) → bool
The equality operator.
inherited