JSValuePointer class

JSValueRef pointer

Constructors

JSValuePointer([Pointer<NativeType>? value])
JSValuePointer.array(List<JSValue> array)
JSValueRef array

Properties

count → int
Pointer array count
final
hashCode → int
The hash code for this object.
no setterinherited
pointer → Pointer<Pointer<NativeType>>
C pointer
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getValue(JSContext context, [int index = 0]) → JSValue
Get JSValue index Array index
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited